@@ -39,6 +39,7 @@ def create_virtualenv(virtualenv_name):
     owner = repo['username']
     github_url = u"git@github.com:{}/{}.git".format(owner, virtualenv_name)
 
+    user_fork_url = None
     github_oauth_token = os.environ.get('GITHUB_OAUTH_TOKEN')
     if github_oauth_token:
         # Create a fork
@@ -46,14 +47,17 @@ def create_virtualenv(virtualenv_name):
         fork_url = "https://api.github.com/repos/{}/{}/forks".format(owner, repo_name)
         res = requests.post(fork_url, headers=headers)
         if res.ok:
-            github_url = res.json['ssh_url']
+            user_fork_url = res.json['ssh_url']
         else:
             print "GITHUB_OAUTH_TOKEN did not have the right oauth scope"
 
     call_virtualenv_command("mkvirtualenv {}".format(virtualenv_name))
     dev_path = os.path.expanduser(os.environ.get("SUPERWRAP_DIR", "~/Development"))
     os.chdir(dev_path)
-    call_virtualenv_command("git clone {}".format(github_url))
+    call_virtualenv_command(u"git clone {}".format(github_url))
     os.chdir(virtualenv_name)
+    call_virtualenv_command(u"git remote rm origin")
+    call_virtualenv_command(u"git remote add origin {}".format(user_fork_url))
+
     call_virtualenv_command("python setup.py develop")
     print u"Setup {}:{} repo for development".format(owner, virtualenv_name)
